## $Id: export.py 12601 2015-02-11 21:38:41Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for pcn customer objects and subobjects.
"""
import grok
from waeup.ikoba.customers.export import (
    CustomerExporter, CustomerDocumentExporterBase, ContractExporterBase)
from ikobacustom.pcn.customers.interfaces import (
    IPCNCustomer, IPCNCustomerJPGDocument,
    IPCNCustomerPDFDocument,
    IRONContractProcess,
    IROPContractProcess,
    IRPRContractProcess,
    IRPCContractProcess,
    IIPPMVLContractProcess)
from ikobacustom.pcn.interfaces import MessageFactory as _

class PCNCustomerExporter(CustomerExporter):
    """Exporter for Customers.
    """
    iface = IPCNCustomer
    title = _(u'PCN Customers')


class PCNCustomerJPGDocumentExporter(CustomerDocumentExporterBase):
    """Exporter for documents.
    """
    grok.name('pcncustomerjpgdocuments')
    iface = IPCNCustomerJPGDocument
    title = _(u'PCN Customer JPG Documents')
    class_name = 'PCNCustomerJPGDocument'

class PCNCustomerPDFDocumentExporter(CustomerDocumentExporterBase):
    """Exporter for documents.
    """
    grok.name('pcncustomerpdfdocuments')
    iface = IPCNCustomerPDFDocument
    title = _(u'PCN Customer PDF Documents')
    class_name = 'PCNCustomerPDFDocument'


class RONContractExporter(ContractExporterBase):
    """Exporter for Contract instances.
    """
    grok.name('roncontracts')
    iface = IRONContractProcess
    title = _(u'Retention of Name Contracts')
    class_name = 'RONContract'


class ROPContractExporter(ContractExporterBase):
    """Exporter for Contract instances.
    """
    grok.name('ropcontracts')
    iface = IROPContractProcess
    title = _(u'Registration of Premises Contracts')
    class_name = 'ROPContract'

class RPRContractExporter(ContractExporterBase):
    """Exporter for Contract instances.
    """
    grok.name('rprcontracts')
    iface = IRPRContractProcess
    title = _(u'Registration in the Provisional Register Contracts')
    class_name = 'RPRContract'

class RPCContractExporter(ContractExporterBase):
    """Exporter for Contract instances.
    """
    grok.name('rpccontracts')
    iface = IRPCContractProcess
    title = _(u'Registration as Pharmaceutical Chemist Contracts')
    class_name = 'RPCContract'

class IPPMVLContractExporter(ContractExporterBase):
    """Exporter for Contract instances.
    """
    grok.name('ippmvlcontracts')
    iface = IIPPMVLContractProcess
    title = _(u'Issuance of Patent and Proprietary Medicines Vendors Licenses')
    class_name = 'IPPMVLContract'
